<?php

namespace Drupal\chatbro;

use Symfony\Component\HttpFoundation\RequestStack;
use Drupal\Core\Database\Connection;
use Drupal\Core\StringTranslation\TranslationInterface;
use Symfony\Component\DependencyInjection\ContainerInterface;
use Drupal\Core\DependencyInjection\ContainerInjectionInterface;
use Drupal\Core\Language\LanguageManagerInterface;
use Drupal\Core\Session\AccountInterface;

class ChatbroService implements ContainerInjectionInterface
{
  protected $stringTranslation;
  protected $database;
  protected $requestStack;
  protected $languageManager;
  protected $currentUser;
  protected $config;

  public function __construct(
    Connection $database,
    RequestStack $request_stack,
    TranslationInterface $string_translation,
    LanguageManagerInterface $language_manager,
    AccountInterface $current_user
  ) {
    $this->database = $database;
    $this->requestStack = $request_stack;
    $this->stringTranslation = $string_translation;
    $this->languageManager = $language_manager;
    $this->currentUser = \Drupal\user\Entity\User::load(\Drupal::currentUser()->id());
    $this->config = \Drupal::config('chatbro.settings');
  }

  /**
   * {@inheritdoc}
   */
  public static function create(ContainerInterface $container)
  {
    return new static(
      $container->get('database'),
      $container->get('request_stack'),
      $container->get('string_translation'),
      $container->get('language_manager'),
      $container->get('current_user')
    );
  }

  public function isFrontPage()
  {
    return \Drupal::service('path.matcher')->isFrontPage();
  }

  public function getPath()
  {
    return \Drupal::service('path.current')->getPath();
  }

  public function getSiteBaseUrl()
  {
    $request = $this->requestStack->getCurrentRequest();
    if ($request) {
      return $request->getSchemeAndHttpHost();
    }
    return NULL;
  }

  public function getRequestVar($var_name)
  {
    $request = $this->requestStack->getCurrentRequest();
    $filter = 'STRING';

    if ($var_name == 'chatbro_chat_selected_pages') {
      $filter = 'HTML';
    }

    return $request->request->get($var_name, null, $filter);
  }

  /**
   * Example method to query the database.
   */
  public function getDB()
  {
    return $this->database;
  }

  public function isUserAuthenticated()
  {
    return !$this->currentUser->isAnonymous();
  }

  public function getUserAvatar()
  {

    $entity = $this->currentUser->get('user_picture')->entity;

    if (is_null($entity)) {
      return null;
    }

    $avatar_url = $this->currentUser->get('user_picture')->entity->getFileUri();

    if (is_null($avatar_url)) {
      return null;
    }

    return \Drupal::service('file_url_generator')->generateAbsoluteString($avatar_url);
  }

  public function getUserId()
  {
    return $this->currentUser->id();
  }

  public function getUserDisplayName()
  {
    return $this->currentUser->getAccountName();
  }

  public function getUserFullName()
  {
    return $this->currentUser->getDisplayName();
  }

  public function isAdmin()
  {
    return $this->currentUser->hasPermission('administer site configuration');
  }

  public function getUserPath()
  {
    return \Drupal\Core\Url::fromRoute('entity.user.canonical', ['user' => $this->currentUser->id()])->setAbsolute()->toString();
  }

  public function getTranslatedString($message)
  {
    return $this->config->get($message);
  }

  public function getLocale()
  {
    return $this->languageManager->getCurrentLanguage()->getId();
  }
}