<?php
/**
 * @copyright   Copyright (C) Chatbro. All rights reserved.
 * @license     GNU General Public License version 2 or later.
 */

namespace Drupal\chatbro\Library\Chatbroapp\Backends;

defined('CHATBROENGINE') || die();

use Drupal\chatbro\Library\Chatbroapp\Interfaces\IcbroUtilsBackend;
use Drupal\chatbro\Library\Chatbroapp\Api\CbroApi;

class CbroUtilsBackend implements IcbroUtilsBackend
{
	private static $scripts_count = 0;
	private static $styles_count = 0;
	private $cms;

	public function __construct($cms)
	{
		$this->cms = $cms;
	}

	function get_site_url()
	{
		return $this->cms->getStoreUrl();
	}

	function generated_scripts()
	{
		$get_chats = "/admin/config/chatbro/gc";
		$create_chat = "/admin/config/chatbro/cc";
		$delete_chat = "/admin/config/chatbro/dc";
		$update_chat = "/admin/config/chatbro/uc";
		$save_settings = "/admin/config/chatbro/ss";
		?>

		<script>
			var cBroGlobals = {
				saveSettingsUrl: "<?php echo $save_settings; ?>",
				createChatUrl: "<?php echo $create_chat; ?>",
				deleteChatUrl: "<?php echo $delete_chat; ?>",
				updateChatUrl: "<?php echo $update_chat; ?>",
				getFaqUrl: "/faq/get",
				getChatsUrl: "<?php echo $get_chats; ?>",
				cms: "<?php echo CbroApi::get_platform_name(); ?>",
				shortcodeTemplateType: '',
				chatShortcodeTemplate: '[chatbro id="%s", static="true"]',
				childShortcodeTemplate: '[chatbro id="%s", child="true", title="Child chat %s"]',
				dropDownConflict: false
			};
		</script>
		<?php
	}

	function get_site_domain()
	{
		$url = self::get_site_url();
		if (!preg_match('/^.+:\/\/([^\/\:]+)/', $url, $m)) {
			return '';
		}

		return $m[1];
	}

	function get_platform()
	{
		return 'drupal-plugin-' . 1 . '.' . 2;
	}

	function is_front_page()
	{
		return $this->cms->isFrontPage();
	}

	function match_path($path, $patterns)
	{
		$to_replace = ['/(\r\n?|\n)/', '/\\\\\*/'];
		$replacements = ['|', '.*'];
		$patterns_quoted = preg_quote($patterns, '/');
		$regexps =
			'/^(' .
			preg_replace($to_replace, $replacements, $patterns_quoted) .
			')$/';
		return (bool) preg_match($regexps, $path);
	}

	function check_path($display, $selected_pages)
	{
		$full_url = $this->cms->getPath();
		$page_match = false;
		$selected_pages = trim($selected_pages);

		if ($selected_pages != '') {
			if (function_exists('mb_strtolower')) {
				$pages = mb_strtolower($selected_pages);
				$path = mb_strtolower($full_url);
			} else {
				$pages = strtolower($selected_pages);
				$path = strtolower($full_url);
			}

			$page_match = self::match_path($path, $pages);

			if ($display == 'except_listed') {
				$page_match = !$page_match;
			}
		}

		return $page_match;
	}

	function enque_script()
	{
	}

	function enque_style()
	{
	}

	function translate($text)
	{
		return $this->cms->translate($text);
	}

	function get_locale()
	{
		return $this->cms->getLocale();
	}

	function get_request_var($var_name)
	{
		return $this->cms->getRequestVar($var_name);
	}

	function get_home_url()
	{
		return $this->cms->getStoreUrl();
	}

	function get_default_profile_url()
	{
		return $this->cms->getStoreUrl();
	}

	function get_support_chat_data_offset_top()
	{
		return 53;
	}
}

?>