<?php
/**
 * @copyright   Copyright (C) Chatbro. All rights reserved.
 * @license     GNU General Public License version 2 or later.
 */

namespace Drupal\chatbro\Library;

defined('CHATBROENGINE') || die();

use Drupal\chatbro\Library\Chatbroapp\Shortcodes\CbroShortCode;
use Drupal\chatbro\Library\Chatbroapp\Backends\CbroUserBackend;
use Drupal\chatbro\Library\Chatbroapp\Common\CbroCommon;
use Drupal\chatbro\Library\Chatbroapp\Users\CbroUser;
use Drupal\chatbro\Library\Chatbroapp\Admin\CbroAdmin;
use Drupal\chatbro\Library\Chatbroapp\Utils\CbroUtils;
use Drupal\chatbro\Library\Chatbroapp\Settings\CbroSettings;
use Drupal\chatbro\Library\Chatbroapp\Chats\CbroChats;
use Drupal\chatbro\Library\Chatbroapp\Api\CbroApi;
use Drupal\chatbro\Library\Chatbroapp\Chats\CbroDisplayChat;
use Drupal\chatbro\Library\Chatbroapp\Permissions\CbroPermissions;
use Drupal\chatbro\Library\Chatbroapp\Backends\CbroUtilsBackend;
use Drupal\chatbro\Library\Chatbroapp\Backends\CbroAdminBackend;
use Drupal\chatbro\Library\Chatbroapp\Backends\CbroSettingsBackend;
use Drupal\chatbro\Library\Chatbroapp\Backends\CbroChatsBackend;
use Drupal\chatbro\Library\Chatbroapp\Backends\CbroApiBackend;
use Drupal\chatbro\Library\Chatbroapp\Backends\CbroPermissionsBackend;


class Chatbrochats
{
	public $store_name;
	public $store_id = 1;

	private $chatbroService;

	public function __construct()
	{
		$this->chatbroService = \Drupal::service('chatbro.chatbro_service');
	}

	public function getStoreUrl()
	{
		return $this->chatbroService->getSiteBaseUrl();
	}

	public function isFrontPage()
	{
		return $this->chatbroService->isFrontPage();
	}

	public function getPath()
	{
		return $this->chatbroService->getPath();
	}

	public function getRequestVar($var_name)
	{
		return $this->chatbroService->getRequestVar($var_name);
	}

	public function getDb()
	{
		return $this->chatbroService->getDB();
	}
	
	public function translate($message)
	{
		return $this->chatbroService->getTranslatedString($message);
	}

	public function getLocale()
	{
		return $this->chatbroService->getLocale();
	}

	public function isUserAuthenticated() {
		return $this->chatbroService->isUserAuthenticated();
	}

	public function getUserId()
	{
	  return $this->chatbroService->getUserId();
	}
  
	public function getUserDisplayName()
	{
	  return $this->chatbroService->getUserDisplayName();
	}
	
	public function getUserPath()
	{
	  return $this->chatbroService->getUserPath();
	}
	
	public function getUserAvatar()
	{
	  return $this->chatbroService->getUserAvatar();
	}

	public function isAdmin()
	{
	  return $this->chatbroService->isAdmin();
	}
  
	public function getUserFullName()
	{
	  return $this->chatbroService->getUserFullName();
	}

	public function getChatbroPanel()
	{
		return CbroAdmin::display();
	}

	public function getChats()
	{
		return CbroAdmin::get_chats();
	}

	public function deleteChat()
	{
		return CbroAdmin::delete_chat();
	}

	public function updateChat()
	{
		return CbroAdmin::update_chat();
	}

	public function createChat()
	{
		return CbroAdmin::create_chat();
	}

	public function saveSettings()
	{
		return CbroAdmin::save_settings();
	}

	public function getShortcodeInstance()
	{
		return CBroShortCode::get_instance();
	}

	public function displayChatById($chatId) 
	{
		return (
			new CbroDisplayChat(
				CbroChats::get($chatId)
			)
		)->get_static_chat_code();
	}


	public function displayChats()
	{
		$result = '';

		foreach (CbroChats::iterator() as $name => $chat) {
			$result .= (
				new CbroDisplayChat(
					$chat
				)
			)->get_sitewide_popup_chat_code();
		}

		return $result;
	}
	
	public function getChatsAsOptions()
	{
		$options = [];

		foreach (CbroChats::iterator() as $chat) {
			$options[$chat->get_id()] = $chat->get_title();
		}

		return $options;
	}

	public function init()
	{
		CbroUtils::init(new CbroUtilsBackend($this));
		CbroCommon::init($this);
		CbroAdmin::init(new CbroAdminBackend());
		CbroSettings::init(new CbroSettingsBackend());
		CbroChats::init(new CbroChatsBackend());
		CbroApi::init(new CbroApiBackend());
		CbroUser::init(new CbroUserBackend($this));
		CbroPermissions::init(new CbroPermissionsBackend());

		if (!class_exists('CBroShortCode')) {
			CbroShortCode::get_instance();
		}

		CbroChats::init_chats();
	}
}