<?php

namespace Drupal\chatbro\Plugin\Block;

use Drupal\Core\Block\BlockBase;
use Drupal\chatbro\Library\Chatbrochats;
use Drupal\Core\Form\FormStateInterface;

/**
 * Provides a block with a simple text.
 *
 * @block(
 *   id = "chatbro_block",
 *   admin_label = @Translation("Chatbro block"),
 * )
 */
class ChatbroBlock extends BlockBase
{
  /**
   * {@inheritdoc}
   */
  public function build()
  {
    if (!defined('CHATBROENGINE')) {
      define('CHATBROENGINE', 1);
    }

    $chatbro = new Chatbrochats();
    $chatbro->init();

    return [
      '#theme' => 'chatbro_block',
      '#html_block' => $chatbro->displayChatById($this->configuration['chatbro_block_chat_id']),
    ];
  }

  /**
   * {@inheritdoc}
   */
  public function defaultConfiguration()
  {
    return [
      'label_display' => FALSE,
      'chatbro_block_chat_id' => $this->t(''),
    ];
  }

  /**
   * {@inheritdoc}
   */
  public function getCacheMaxAge()
  {
    return -1;
  }

  /**
   * {@inheritdoc}
   */
  public function blockForm($form, FormStateInterface $form_state)
  {

    if (!defined('CHATBROENGINE')) {
      define('CHATBROENGINE', 1);
    }

    $chatbro = new Chatbrochats();
    $chatbro->init();

    $form['chatbro_block_chat_id'] = [
      '#description' => $this->t('The chat will be non-movable and will span the entire length of the block. Option "Show popup chat" from the plugin settings will be ignored.'),
      '#type' => 'select',
      '#title' => $this->t('Select chat'),
      '#options' => $chatbro->getChatsAsOptions(),
      '#default_value' => 'option1',
    ];

    return $form;
  }

  /**
   * {@inheritdoc}
   */
  public function blockSubmit($form, FormStateInterface $form_state)
  {
    $values = $form_state->getValues();
    $this->configuration['chatbro_block_chat_id'] = $values['chatbro_block_chat_id'];
  }

  /**
   * {@inheritdoc}
   */
  public function blockValidate($form, FormStateInterface $form_state)
  {
  }
}